@@ -5,7 +5,8 @@ Command Center, translating JSON responses into objects from the :py:mod:`banyan
 
 import logging
 import os
-from typing import Dict, Any, List, Union
+import sys
+from typing import Dict, Any, List, Union, Callable
 
 import requests
 from requests.auth import AuthBase
@@ -23,6 +24,7 @@ from banyan.api.user import UserAPI
 from banyan.core.exc import BanyanError
 
 JsonListOrObj = Union[List, Dict]
+ProgressCallback = Callable[[str, str, int, int], None]
 
 
 class BanyanApiClient:
@@ -76,9 +78,10 @@ class BanyanApiClient:
                  log: logging.Logger = None) -> None:
         self._debug = debug
         self._log = log
+        self._progress_callback = None
+        self._access_token = None
         self._api_url = self._normalize_url(api_server_url or os.getenv('BANYAN_API_URL')
                                             or BanyanApiClient.DEFAULT_API_URL)
-        self._access_token = None
         self._refresh_token = refresh_token or os.getenv('BANYAN_REFRESH_TOKEN')
         if not self._refresh_token:
             raise BanyanError("Refresh token must be set")
@@ -185,24 +188,46 @@ class BanyanApiClient:
             headers['Content-Type'] = self.JSON_TYPE
         return self._request(method=method, url=uri, params=params, data=data, headers=headers, json=json).json()
 
+    @property
+    def progress_callback(self) -> ProgressCallback:
+        return self._progress_callback
+
+    @progress_callback.setter
+    def progress_callback(self, value: ProgressCallback) -> None:
+        self._progress_callback = value
+
+    def _do_progress_callback(self, method: str, uri: str, count: int, total: int) -> None:
+        if self._progress_callback:
+            try:
+                self._progress_callback(method, uri, count, total)
+            except Exception as ex:
+                err_msg = f'{ex.__class__.__name__} exception in progress callback: {ex.args[0]}'
+                if self._log:
+                    self._log.error(err_msg)
+                else:
+                    print(err_msg, file=sys.stderr)
+
     def paged_request(self, method: str, uri: str, params: Dict[str, Any] = None, data: Any = None,
-                      json: str = None, headers: Dict[str, str] = None, accept: str = None) -> JsonListOrObj:
-        skip = 0
-        limit = 1000
+                      json: str = None, headers: Dict[str, str] = None, accept: str = None,
+                      progress_callback: ProgressCallback = None) -> JsonListOrObj:
         params = params or dict()
+        skip = params.get('skip', 0)
+        limit = params.get('limit', 1000)
         all_results = list()
+        callback = progress_callback or self._progress_callback
 
         while True:
-            params['Skip'] = skip
-            params['Limit'] = limit
+            params['skip'] = skip
+            params['limit'] = limit
             results = self.api_request(method, uri, params, data, json, headers, accept)
             for key in results.keys():
                 logging.debug(f'Looking for {key} in {uri}')
-                if key in uri:
+                if key in uri or key == 'data':
                     if len(results[key]) == 0:
                         return all_results
                     all_results.extend(results[key])
                     logging.debug(f'Found {key}, result count = {len(results[key])}, total count = {len(all_results)}')
+                    self._do_progress_callback(method, uri, len(all_results), results.get('count', -1))
                     skip += limit
 
     @property
